==> 2.4.zip: piwigo/language/zh_TW/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | Piwigo - a PHP based photo gallery                                    |
// +-----------------------------------------------------------------------+
// | Copyright(C) 2008-2012 Piwigo Team                  http://piwigo.org |
// | Copyright(C) 2003-2008 PhpWebGallery Team    http://phpwebgallery.net |
// | Copyright(C) 2002-2003 Pierrick LE GALL   http://le-gall.net/pierrick |
// +-----------------------------------------------------------------------+
// | This program is free software; you can redistribute it and/or modify  |
// | it under the terms of the GNU General Public License as published by  |
// | the Free Software Foundation                                          |
// |                                                                       |
// | This program is distributed in the hope that it will be useful, but   |
// | WITHOUT ANY WARRANTY; without even the implied warranty of            |
// | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU      |
// | General Public License for more details.                              |
// |                                                                       |
// | You should have received a copy of the GNU General Public License     |
// | along with this program; if not, write to the Free Software           |
// | Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, |
// | USA.                                                                  |
// +-----------------------------------------------------------------------+

$lang['Installation'] = '安裝';
$lang['Basic configuration'] = '基本設置';
$lang['Default gallery language'] = '圖庫默認語言';
$lang['Database configuration'] = '數據庫設置';
$lang['Admin configuration'] = '管理員帳戶設置';
$lang['Start Install'] = '開始安裝';
$lang['mail address must be like xxx@yyy.eee (example : jack@altern.org)'] = '郵箱地址格式 xxx@yyy.eee (例 : jack@altern.org)';
$lang['Webmaster login'] = '管理員';
$lang['It will be shown to the visitors. It is necessary for website administration'] = '所有用戶都能看到此帳戶。必須提供此帳戶來管理網站';
$lang['Connection to server succeed, but it was impossible to connect to database'] = '服務器連接正常，但是無法連接到數據庫';
$lang['Can\'t connect to server'] = '無法連接到服務器';
$lang['Host'] = 'MySQL主機地址';
$lang['localhost, sql.multimania.com, toto.freesurf.fr'] = 'localhost, sql.multimania.com, toto.freesurf.fr';
$lang['User'] = '用戶';
$lang['user login given by your host provider'] = '主機用戶名';
$lang['Password'] = '密碼';
$lang['user password given by your host provider'] = '主機用戶密碼';
$lang['Database name'] = '數據庫名稱';
$lang['also given by your host provider'] = '在主機設定的數據庫名稱';
$lang['Database table prefix'] = '表名稱前綴';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = '所有的表名稱都加此前綴(有利於數據庫管理)';
$lang['enter a login for webmaster'] = '請輸入網管名';
$lang['webmaster login can\'t contain characters \' or "'] = '網管名不應包含字符 " 和 \'';
$lang['please enter your password again'] = '請再次輸入密碼';
$lang['Webmaster password'] = '密碼';
$lang['Keep it confidential, it enables you to access administration panel'] = '請小心保管好此密碼，它允許你操作管理板塊。';
$lang['Password [confirm]'] = '密碼 [ 確認 ]';
$lang['verification'] = '核實';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '需要幫助？ 請到<a href="%s">Piwigo論壇</a>提出你的問題.';
$lang['Webmaster mail address'] = '管理員Email地址';
$lang['Visitors will be able to contact site administrator with this mail'] = '遊客通過此Email跟你聯繫';
$lang['PHP 5 is required'] = '必須PHP 5版本';
$lang['It appears your webhost is currently running PHP %s.'] = '你主機PHP版本好像是PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo試著創建或修改.htaccess文件來轉換到PHP 5。';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = '注意；你也可以自己修改設置PHP然後重新啟動Piwigo。';
$lang['Try to configure PHP 5'] = '試試配置PHP 5';
$lang['Sorry!'] = '對不起!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo不能設置PHP 5.';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = '你應該聯繫你的主機管理員並向其請教如何設置PHP 5.';
$lang['Hope to see you back soon.'] = '希望下次再見到你...';
$lang['Congratulations, Piwigo installation is completed'] = '恭喜，Piwigo 已安裝完成。';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = '另一個解決辦法是，將以上文本框裡的文本拷貝到 "local/config/database.inc.php" 文件裡（注意：database.inc.php 必須只能包含此文本框裡的內容，沒有換行或者空格字符）';
$lang['Creation of config file local/config/database.inc.php failed.'] = '創建 local/config/database.inc.php 文件失敗.';
$lang['Download the config file'] = '下載配置文件';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = '您可以下載配置文件，然後上傳到 local/config 目錄以完成您的安裝.';
$lang['Just another Piwigo gallery'] = '另一本Piwigo相片集';
$lang['Welcome to my photo gallery'] = '歡迎進入我的相片集';
$lang['Welcome to your new installation of Piwigo!'] = '歡迎安裝Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = '如有任何問題，請至我們的論壇提出：%s ';
?>

==> 14.5.0.zip: piwigo/language/zh_TW/install.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+

$lang['Installation'] = '安裝';
$lang['Basic configuration'] = '基本設置';
$lang['Default gallery language'] = '圖庫默認語言';
$lang['Database configuration'] = '數據庫設置';
$lang['Admin configuration'] = '管理員帳戶設定';
$lang['Start Install'] = '開始安裝';
$lang['It will be shown to the visitors. It is necessary for website administration'] = '所有用戶都能看到此帳戶。必須提供此帳戶來管理網站';
$lang['Connection to server succeed, but it was impossible to connect to database'] = '服務器連接正常，但是無法連接到數據庫';
$lang['Can\'t connect to server'] = '無法連接到服務器';
$lang['Host'] = 'MySQL主機地址';
$lang['User'] = '用戶';
$lang['user login given by your host provider'] = '主機用戶名';
$lang['user password given by your host provider'] = '主機用戶密碼';
$lang['Database name'] = '數據庫名稱';
$lang['also given by your host provider'] = '在主機設定的數據庫名稱';
$lang['Database table prefix'] = '表名稱前綴';
$lang['database tables names will be prefixed with it (enables you to manage better your tables)'] = '所有的表名稱都加此前綴(有利於數據庫管理)';
$lang['enter a login for webmaster'] = '請輸入網管名';
$lang['webmaster login can\'t contain characters \' or "'] = '網管名不應包含字符 " 和 \'';
$lang['please enter your password again'] = '請再次輸入密碼';
$lang['Keep it confidential, it enables you to access administration panel'] = '請小心保管好此密碼，它允許你操作管理板塊。';
$lang['Password [confirm]'] = '密碼 [ 確認 ]';
$lang['verification'] = '核實';
$lang['Need help ? Ask your question on <a href="%s">Piwigo message board</a>.'] = '需要幫助？ 請到<a href="%s">Piwigo論壇</a>提出你的問題.';
$lang['Visitors will be able to contact site administrator with this mail'] = '遊客通過此Email跟你聯繫';
$lang['PHP 5 is required'] = '必須PHP 5.2版本';
$lang['It appears your webhost is currently running PHP %s.'] = '你主機PHP版本好像是PHP %s.';
$lang['Piwigo may try to switch your configuration to PHP 5 by creating or modifying a .htaccess file.'] = 'Piwigo試著創建或修改.htaccess文件來轉換到PHP 5.2。';
$lang['Note you can change your configuration by yourself and restart Piwigo after that.'] = '注意；你也可以自己修改設置PHP然後重新啟動Piwigo。';
$lang['Try to configure PHP 5'] = '試試配置PHP 5.2';
$lang['Sorry!'] = '對不起!';
$lang['Piwigo was not able to configure PHP 5.'] = 'Piwigo不能設置PHP 5.2';
$lang["You may referer to your hosting provider's support and see how you could switch to PHP 5 by yourself."] = '你應該聯繫你的主機管理員並向其請教如何設置PHP 5.';
$lang['Hope to see you back soon.'] = '希望下次再見到你...';
$lang['Congratulations, Piwigo installation is completed'] = '恭喜，Piwigo 已安裝完成。';
$lang['An alternate solution is to copy the text in the box above and paste it into the file "local/config/database.inc.php" (Warning : database.inc.php must only contain what is in the textarea, no line return or space character)'] = '另一個解決辦法是，將以上文本框裡的文本拷貝到 "local/config/database.inc.php" 文件裡（注意：database.inc.php 必須只能包含此文本框裡的內容，沒有換行或者空格字符）';
$lang['Creation of config file local/config/database.inc.php failed.'] = '創建 local/config/database.inc.php 文件失敗.';
$lang['Download the config file'] = '下載配置文件';
$lang['You can download the config file and upload it to local/config directory of your installation.'] = '您可以下載配置文件，然後上傳到 local/config 目錄以完成您的安裝.';
$lang['Just another Piwigo gallery'] = '另一本Piwigo相片集';
$lang['Welcome to my photo gallery'] = '歡迎進入我的相片集';
$lang['Welcome to your new installation of Piwigo!'] = '歡迎安裝Piwigo!';
$lang['Don\'t hesitate to consult our forums for any help : %s'] = '如有任何問題，請至我們的論壇提出：%s ';
$lang['localhost or other, supplied by your host provider'] = '本地主機或其它，由你的主機提供商提供';
$lang['You may referer to your hosting provider\'s support and see how you could switch to PHP 5 by yourself.'] = '你應該聯繫你的主機管理員並向其請教如何設置PHP 5.2';
$lang['PHP version %s required (you are running on PHP %s)'] = '需要 PHP %s 以上的版本（目前執行中的是 PHP %s）';
